"use strict";
const common_vendor = require("../../common/vendor.js");
const utils_city = require("../../utils/city.js");
const _sfc_main = {
  data() {
    return {
      // 产品列表
      addrList: [],
      // 请求参数
      requestParam: {
        page: 1,
        status: 0
      },
      // 保存地址
      addrRequest: {
        id: 0,
        contact_name: "",
        contact_phone: "",
        contact_province: "",
        contact_city: "",
        contact_area: "",
        contact_addr: "",
        is_default: 0
      },
      // 是否最后一页
      isLast: false,
      // 是否请求中
      isReqing: false,
      // 所在地区
      cityArray: [[], [], []],
      cityValue: [0, 0, 0],
      // 自动弹出
      autoShowForm: false,
      // 异步通知
      AddrEmit: false
    };
  },
  onLoad(param) {
    this.AddrEmit = param.notify == "addr" ? true : false;
    this.autoShowForm = param.type == "create" ? true : false;
    this.getList();
  },
  onReady() {
    if (this.autoShowForm) {
      var that = this;
      setTimeout(function() {
        that.openForm();
      }, 500);
    }
  },
  onShow() {
    this.cityArray.splice(0, 1, utils_city.getProvinces());
    this.cityArray.splice(1, 1, utils_city.getMyCity(this.cityValue[0]));
    this.cityArray.splice(2, 1, utils_city.getAreas(this.cityValue[0], this.cityValue[1]));
    this.addrRequest.contact_province = this.cityArray[0][this.cityValue[0]];
    this.addrRequest.contact_city = this.cityArray[1][this.cityValue[1]];
    this.addrRequest.contact_area = this.cityArray[2][this.cityValue[2]];
  },
  methods: {
    // 获取列表
    getList() {
      this.$http.request("api/custom_addr/get_list").then((callback) => {
        if (callback.code == "success") {
          this.addrList = callback.data;
          if (this.AddrEmit)
            common_vendor.index.$emit("addr_list_change", { list: this.addrList });
        }
      });
    },
    // 打开弹窗
    openForm(item) {
      if (!item) {
        this.addrRequest.id = 0;
        this.addrRequest.contact_name = "";
        this.addrRequest.contact_phone = "";
        this.addrRequest.contact_addr = "";
        this.addrRequest.is_default = 0;
      } else {
        this.addrRequest = item;
      }
      this.$refs.addrForm.open("bottom");
    },
    // 默认开关
    defaultSwitch(e) {
      this.addrRequest.is_default = e.detail.value ? 1 : 0;
    },
    // 弹出层
    popupChange(e) {
      this.show = e.show;
    },
    // 城市修改
    cityChange(e) {
      this.cityValue.splice(e.detail.column, 1, e.detail.value);
      if (e.detail.column == 0) {
        this.cityValue.splice(1, 1, 0);
        this.cityValue.splice(2, 1, 0);
      }
      if (e.detail.column == 1) {
        this.cityValue.splice(2, 1, 0);
      }
      this.cityArray.splice(0, 1, utils_city.getProvinces());
      this.cityArray.splice(1, 1, utils_city.getMyCity(this.cityValue[0]));
      this.cityArray.splice(2, 1, utils_city.getAreas(this.cityValue[0], this.cityValue[1]));
    },
    // 城市选择
    cityFinish(e) {
      this.addrRequest.contact_province = this.cityArray[0][this.cityValue[0]];
      this.addrRequest.contact_city = this.cityArray[1][this.cityValue[1]];
      this.addrRequest.contact_area = this.cityArray[2][this.cityValue[2]];
    },
    // 城市选中
    cityFinish(e) {
      this.addrRequest.contact_province = this.cityArray[0][this.cityValue[0]];
      this.addrRequest.contact_city = this.cityArray[1][this.cityValue[1]];
      this.addrRequest.contact_area = this.cityArray[2][this.cityValue[2]];
    },
    // 保存地址
    saveAddr() {
      if (!this.addrRequest.contact_name) {
        common_vendor.index.showToast({ icon: "none", title: "请填写收件人" });
        return;
      }
      if (this.addrRequest.contact_name.length < 2) {
        common_vendor.index.showToast({ icon: "none", title: "请填写收件人完整姓名" });
        return;
      }
      if (!this.addrRequest.contact_phone) {
        common_vendor.index.showToast({ icon: "none", title: "请填写收件人手机号" });
        return;
      }
      if (!this.addrRequest.contact_addr) {
        common_vendor.index.showToast({ icon: "none", title: "请填写联系地址" });
        return;
      }
      if (this.addrRequest.contact_addr.length < 3) {
        common_vendor.index.showToast({ icon: "none", title: "请填写可用联系地址" });
        return;
      }
      common_vendor.index.showLoading({ mask: true });
      var url = this.addrRequest.id ? "api/custom_addr/edit" : "api/custom_addr/add";
      this.$http.request(url, this.addrRequest, "post").then((re) => {
        common_vendor.index.hideLoading();
        if (re.code != "success") {
          common_vendor.index.showToast({ title: re.msg, icon: "none" });
          return;
        }
        this.getList();
        this.$refs.addrForm.close();
      });
    },
    // 删除地址
    removeAddr(index) {
      this.$http.request("api/custom_addr/del", { id: this.addrList[index].id }, "post").then((re) => {
        common_vendor.index.hideLoading();
        if (re.code != "success") {
          common_vendor.index.showToast({ title: re.msg, icon: "none" });
          return;
        }
        this.addrList.splice(index, 1);
        if (this.AddrEmit)
          common_vendor.index.$emit("addr_list_change", { list: this.addrList });
      });
    },
    // 设置默认
    setDefault(index) {
      if (this.addrList[index].is_default)
        return;
      this.$http.request("api/custom_addr/set_default", { id: this.addrList[index].id }, "post").then((re) => {
        common_vendor.index.hideLoading();
        if (re.code != "success") {
          common_vendor.index.showToast({ title: re.msg, icon: "none" });
          return;
        }
        for (let i in this.addrList) {
          this.addrList[i].is_default = 0;
        }
        this.addrList[index].is_default = 1;
        if (this.AddrEmit)
          common_vendor.index.$emit("addr_list_change", { list: this.addrList });
      });
    }
  }
};
if (!Array) {
  const _easycom_uni_popup2 = common_vendor.resolveComponent("uni-popup");
  _easycom_uni_popup2();
}
const _easycom_uni_popup = () => "../../uni_modules/uni-popup/components/uni-popup/uni-popup.js";
if (!Math) {
  _easycom_uni_popup();
}
function _sfc_render(_ctx, _cache, $props, $setup, $data, $options) {
  return common_vendor.e({
    a: !$data.addrList.length
  }, !$data.addrList.length ? {} : {}, {
    b: common_vendor.f($data.addrList, (item, index, i0) => {
      return {
        a: common_vendor.t(item.contact_name),
        b: common_vendor.t(item.contact_phone),
        c: common_vendor.t(item.contact_province),
        d: common_vendor.t(item.contact_city),
        e: common_vendor.t(item.contact_area),
        f: common_vendor.t(item.contact_addr),
        g: item.is_default ? "../../static/icon/radioed.png" : "../../static/icon/radio.png",
        h: common_vendor.t(item.is_default ? "已默认" : "设为默认"),
        i: common_vendor.n(item.is_default ? "radioed_text" : ""),
        j: common_vendor.o(($event) => $options.setDefault(index), index),
        k: common_vendor.o(($event) => $options.removeAddr(index), index),
        l: common_vendor.o(($event) => $options.openForm(item), index),
        m: index
      };
    }),
    c: common_vendor.o(($event) => $options.openForm()),
    d: $data.isLast
  }, $data.isLast ? {} : {}, {
    e: $data.addrRequest.contact_name,
    f: common_vendor.o(($event) => $data.addrRequest.contact_name = $event.detail.value),
    g: $data.addrRequest.contact_phone,
    h: common_vendor.o(($event) => $data.addrRequest.contact_phone = $event.detail.value),
    i: $data.addrRequest.contact_province
  }, $data.addrRequest.contact_province ? {
    j: common_vendor.t($data.addrRequest.contact_province)
  } : {}, {
    k: $data.addrRequest.contact_city
  }, $data.addrRequest.contact_city ? {
    l: common_vendor.t($data.addrRequest.contact_city)
  } : {}, {
    m: $data.addrRequest.contact_area
  }, $data.addrRequest.contact_area ? {
    n: common_vendor.t($data.addrRequest.contact_area)
  } : {}, {
    o: $data.cityArray,
    p: common_vendor.o((...args) => $options.cityChange && $options.cityChange(...args)),
    q: common_vendor.o((...args) => $options.cityFinish && $options.cityFinish(...args)),
    r: $data.addrRequest.contact_addr,
    s: common_vendor.o(($event) => $data.addrRequest.contact_addr = $event.detail.value),
    t: common_vendor.o((...args) => $options.defaultSwitch && $options.defaultSwitch(...args)),
    v: $data.addrRequest.is_default ? true : false,
    w: common_vendor.o((...args) => $options.saveAddr && $options.saveAddr(...args)),
    x: common_vendor.sr("addrForm", "217e1134-0"),
    y: common_vendor.o($options.popupChange),
    z: common_vendor.p({
      type: "bottom",
      ["background-color"]: "#FFFFFF"
    })
  });
}
const MiniProgramPage = /* @__PURE__ */ common_vendor._export_sfc(_sfc_main, [["render", _sfc_render]]);
wx.createPage(MiniProgramPage);
