"use strict";
const common_vendor = require("../../common/vendor.js");
const common_assets = require("../../common/assets.js");
const _sfc_main = {
  data() {
    return {
      // 购物车列表
      cartList: [],
      // 请求参数
      requestParam: {},
      // 是否全选
      checkedAll: false,
      // 总价
      priceTotal: "0.00",
      // 是否请求中
      isReqing: false
    };
  },
  onLoad() {
  },
  onShow() {
    if (!this.$checkAccess.alterLogin())
      return;
    if (this.isReqing)
      return;
    this.isReqing = true;
    this.checkedAll = 0;
    this.$http.request("api/shop_cart/get_list", this.requestParam).then((re) => {
      this.isReqing = false;
      if (re.code == "success") {
        this.cartList = re.data;
        this.priceHandler();
      }
    });
  },
  onPullDownRefresh() {
    if (!this.$checkAccess.alterLogin())
      return;
    this.$http.request("api/shop_cart/get_list", this.requestParam).then((re) => {
      if (re.code == "success") {
        this.cartList = re.data;
        this.priceHandler();
      }
    });
    common_vendor.index.stopPullDownRefresh();
  },
  onReachBottom() {
  },
  methods: {
    // 数量调整
    changeQuantity(index, number) {
      if (number != 0) {
        this.cartList[index].buy_num = this.cartList[index].buy_num + number;
      }
      if (this.cartList[index].buy_num > this.cartList[index].stock) {
        this.cartList[index].buy_num = this.cartList[index].stock;
        common_vendor.index.showToast({
          title: "购买数量不能大于库存",
          icon: "none"
        });
        return;
      }
      if (this.cartList[index].buy_num < 1) {
        this.cartList[index].buy_num = 1;
        common_vendor.index.showToast({
          title: "数量不可小于1",
          icon: "none"
        });
        return;
      }
      this.$http.request("api/shop_cart/edit", { id: this.cartList[index].id, buy_num: this.cartList[index].buy_num }).then((re) => {
        if (re.code == "success") {
          this.priceHandler();
        } else {
          common_vendor.index.showToast({
            title: re.msg,
            icon: "none"
          });
        }
      });
    },
    // 删除购物车
    deleteCar(index) {
      common_vendor.index.showModal({
        title: "是否删除？",
        success: (re) => {
          if (re.confirm) {
            this.$http.request("api/shop_cart/del", { id: this.cartList[index].id }).then((re2) => {
              if (re2.code == "success") {
                this.cartList.splice(index, 1);
                this.priceHandler();
              }
            });
          }
        }
      });
    },
    checkedItem(index) {
      let checkedAll = 1;
      this.cartList[index].checked = this.cartList[index].checked ? 0 : 1;
      for (let i in this.cartList) {
        if (!this.cartList[i].checked)
          checkedAll = 0;
      }
      this.checkedAll = checkedAll;
      this.priceHandler();
    },
    checkAll() {
      this.checkedAll = this.checkedAll ? 0 : 1;
      for (let index in this.cartList) {
        this.cartList[index].checked = this.checkedAll;
      }
      this.priceHandler();
    },
    priceHandler() {
      let priceTotal = 0;
      for (let index in this.cartList) {
        if (this.cartList[index].checked) {
          priceTotal = this.$decimal.add(priceTotal, this.$decimal.mul(this.cartList[index].price, this.cartList[index].buy_num));
        }
      }
      this.priceTotal = priceTotal.toFixed(2);
    },
    toOrder() {
      let waitList = [];
      for (let index in this.cartList) {
        if (this.cartList[index].checked) {
          if (this.cartList[index].buy_num < 1) {
            common_vendor.index.showToast({ icon: "none", title: "选择的产品至少需要1个" });
            return;
          }
          if (this.cartList[index].buy_num > this.cartList[index].stock) {
            common_vendor.index.showToast({ icon: "none", title: "产品库存不足" });
            return;
          }
          waitList.push(this.cartList[index].id);
        }
      }
      if (!waitList.length) {
        common_vendor.index.showToast({ icon: "none", title: "请选择需要结算的产品" });
        return;
      }
      if (waitList.length > 99) {
        common_vendor.index.showToast({ icon: "none", title: "这么多产品一个预约单写不下哦" });
        return;
      }
      common_vendor.index.navigateTo({
        url: "/pages/car/order?cart_ids=" + waitList.join(",")
      });
    }
  }
};
function _sfc_render(_ctx, _cache, $props, $setup, $data, $options) {
  return common_vendor.e({
    a: !$data.cartList.length
  }, !$data.cartList.length ? {} : {}, {
    b: common_vendor.f($data.cartList, (item, index, i0) => {
      return {
        a: item.checked ? "../../static/icon/checked.png" : "../../static/icon/checkbox.png",
        b: common_vendor.o(($event) => $options.checkedItem(index), index),
        c: item.thumb,
        d: common_vendor.t(item.name),
        e: common_vendor.t(item.spec),
        f: common_vendor.t(item.price),
        g: common_vendor.t(item.market_price),
        h: common_vendor.o(($event) => $options.changeQuantity(index, -1), index),
        i: common_vendor.o(($event) => $options.changeQuantity(index, 0), index),
        j: item.buy_num,
        k: common_vendor.o(($event) => item.buy_num = $event.detail.value, index),
        l: common_vendor.o(($event) => $options.changeQuantity(index, 1), index),
        m: common_vendor.o(($event) => $options.deleteCar(index), index),
        n: index
      };
    }),
    c: common_assets._imports_2,
    d: common_assets._imports_3,
    e: $data.checkedAll ? "../../static/icon/checked.png" : "../../static/icon/checkbox.png",
    f: common_vendor.o(($event) => $options.checkAll()),
    g: common_vendor.t($data.priceTotal),
    h: common_vendor.o(($event) => $options.toOrder())
  });
}
const MiniProgramPage = /* @__PURE__ */ common_vendor._export_sfc(_sfc_main, [["render", _sfc_render]]);
wx.createPage(MiniProgramPage);
