"use strict";
const common_vendor = require("../../common/vendor.js");
const _sfc_main = {
  data() {
    return {
      // 购物车列表
      cartList: [],
      // 优惠券列表
      couponList: [],
      // 请求参数
      requestParam: {
        cart_ids: ""
      },
      // 总价
      priceTotal: "0.00",
      // 优惠券使用
      couponUsed: "去使用 >",
      // 扣减金额
      rebatePrice: 0,
      // 已经选择的优惠券ID
      customCoupon: 0,
      // 地址列表
      addrList: [],
      // 已选地址
      checkedAddr: {
        id: 0,
        contact_name: "",
        contact_phone: "",
        contact_province: "",
        contact_city: "",
        contact_area: "",
        contact_addr: "",
        is_default: 0
      }
    };
  },
  onLoad(param) {
    this.requestParam.cart_ids = param.cart_ids;
    var that = this;
    common_vendor.index.$on("addr_list_change", function(data) {
      that.addrList = data.list;
    });
  },
  onShow() {
    this.$http.request("api/shop_cart/check_list", this.requestParam).then((re) => {
      if (re.code == "success") {
        this.cartList = re.data;
        this.$http.request("api/custom_coupon/get_checked", this.requestParam).then((re2) => {
          if (re2.code == "success") {
            for (let i in re2.data) {
              var totalPrice = 0;
              for (let j in this.cartList) {
                if (re2.data[i].type_id == 1) {
                  var isScope = false;
                  for (let k in re2.data[i].product_scope) {
                    if (re2.data[i].product_scope[k].product_id == this.cartList[j].product_id)
                      isScope = true;
                  }
                  if (isScope) {
                    totalPrice = this.$decimal.add(totalPrice, this.$decimal.mul(this.cartList[j].price, this.cartList[j].buy_num));
                  }
                } else {
                  totalPrice = this.$decimal.add(totalPrice, this.$decimal.mul(this.cartList[j].price, this.cartList[j].buy_num));
                }
              }
              re2.data[i].is_std = totalPrice.toFixed() >= this.$decimal.mul(re2.data[i].std_pay, 1).toFixed();
            }
            this.couponList = re2.data;
          }
        });
        this.priceHandler();
      }
    });
    this.getAddrList();
  },
  onPullDownRefresh() {
    this.$http.request("api/shop_cart/check_list", this.requestParam).then((re) => {
      if (re.code == "success") {
        this.cartList = re.data;
        this.priceHandler();
      }
    });
    common_vendor.index.stopPullDownRefresh();
  },
  onReachBottom() {
  },
  methods: {
    // 地址弹出层
    showAddrPopup() {
      this.$refs.addrPopup.open("bottom");
    },
    // 价格计算
    priceHandler() {
      let priceTotal = 0;
      for (let index in this.cartList) {
        priceTotal = this.$decimal.add(priceTotal, this.$decimal.mul(this.cartList[index].price, this.cartList[index].buy_num));
      }
      priceTotal = this.$decimal.sub(priceTotal, this.rebatePrice);
      this.priceTotal = priceTotal.toFixed(2);
    },
    // 创建订单
    createOrder() {
      if (!this.$checkAccess.alertCity())
        return;
      let productList = [];
      for (let index in this.cartList) {
        if (this.cartList[index].buy_num > 0) {
          productList.push({ product_id: this.cartList[index].product_id, buy_num: this.cartList[index].buy_num, product_skuid: this.cartList[index].skuid });
        }
      }
      if (productList.length <= 0) {
        common_vendor.index.showToast({
          title: "未选择可预约的产品",
          icon: "none"
        });
        return;
      }
      if (!this.checkedAddr.id) {
        common_vendor.index.showToast({
          title: "请选择收货地址",
          icon: "none"
        });
        return;
      }
      let productInfo = [];
      for (let index in this.cartList) {
        if (this.cartList[index].buy_num > 0) {
          productInfo.push({ name: this.cartList[index].name, spec: this.cartList[index].spec, price: this.cartList[index].price });
        }
      }
      productInfo = JSON.stringify(productInfo);
      let encodedArray = encodeURIComponent(productInfo);
      productList = JSON.stringify(productList);
      this.$http.request("api/orders/create", { "product_list": productList, "custom_coupon_id": this.customCoupon, "is_cart": 1, "addr_id": this.checkedAddr.id }, "post").then((re) => {
        if (re.code == "success") {
          common_vendor.index.redirectTo({ url: `/pages/orders/completion?params=${encodedArray}` });
          return;
        } else {
          common_vendor.index.showToast({ title: re.msg, icon: "none" });
        }
      });
    },
    // 弹出优惠券
    popupCoupon() {
      this.$refs.popup.open();
    },
    // 选择优惠券
    checkedCoupon(index) {
      this.couponList[index].checked = this.couponList[index].checked ? 0 : 1;
      for (let i in this.couponList) {
        if (index != i)
          this.couponList[i].checked = 0;
      }
      if (!this.couponList[index].checked)
        this.couponUsed = "去使用 >";
      this.customCoupon = this.couponList[index].checked ? this.couponList[index].id : 0;
      this.couponRebate();
      this.priceHandler();
      this.$refs.popup.close();
    },
    // 计算优惠券扣减
    couponRebate() {
      this.rebatePrice = 0;
      for (let i in this.couponList) {
        if (!this.couponList[i].checked) {
          continue;
        }
        var totalPrice = 0;
        for (let j in this.cartList) {
          if (this.couponList[i].type_id == 1) {
            var isScope = false;
            for (let k in this.couponList[i].product_scope) {
              if (this.couponList[i].product_scope[k].product_id == this.cartList[j].product_id)
                isScope = true;
            }
            if (isScope)
              totalPrice = this.$decimal.add(totalPrice, this.$decimal.mul(this.cartList[j].price, this.cartList[j].buy_num));
          } else {
            totalPrice = this.$decimal.add(totalPrice, this.$decimal.mul(this.cartList[j].price, this.cartList[j].buy_num));
          }
        }
        if (totalPrice.toFixed() >= this.$decimal.mul(this.couponList[i].std_pay, 1).toFixed()) {
          let rebatePrice = 0;
          if (this.couponList[i].rebate_type == 1) {
            rebatePrice = this.$decimal.mul(this.couponList[i].rebate, 1);
            this.couponUsed = "￥-" + rebatePrice.toFixed(2);
          }
          if (this.couponList[i].rebate_type == 2) {
            rebatePrice = this.$decimal.mul(totalPrice, this.couponList[i].rebate);
            rebatePrice = this.$decimal.sub(totalPrice, rebatePrice.mul(0.1));
            this.couponUsed = "￥-" + rebatePrice.toFixed(2);
          }
          if (this.couponList[i].rebate_type == 3) {
            this.couponUsed = "送" + (this.couponList[i].rebate_scope.length ? this.couponList[i].rebate_scope[0].product_name : "");
          }
          this.rebatePrice = rebatePrice.toFixed(2);
        }
      }
    },
    // 选择地址
    checkedAddrItem(item) {
      this.checkedAddr = item;
      this.$refs.addrPopup.close();
    },
    getAddrList() {
      this.$http.request("api/custom_addr/get_list").then((callback) => {
        if (callback.code == "success") {
          this.addrList = callback.data;
          if (this.addrList.length) {
            for (let i in this.addrList) {
              if (this.addrList[i].is_default)
                this.checkedAddr = this.addrList[i];
            }
            if (!this.checkedAddr.id) {
              this.checkedAddr = this.addrList[this.addrList.length - 1];
            }
          }
        }
      });
    }
  }
};
if (!Array) {
  const _easycom_uni_popup2 = common_vendor.resolveComponent("uni-popup");
  _easycom_uni_popup2();
}
const _easycom_uni_popup = () => "../../uni_modules/uni-popup/components/uni-popup/uni-popup.js";
if (!Math) {
  _easycom_uni_popup();
}
function _sfc_render(_ctx, _cache, $props, $setup, $data, $options) {
  return common_vendor.e({
    a: !$data.checkedAddr.id
  }, !$data.checkedAddr.id ? {} : {}, {
    b: common_vendor.t($data.checkedAddr.contact_name),
    c: common_vendor.t($data.checkedAddr.contact_phone),
    d: common_vendor.t($data.checkedAddr.contact_province),
    e: common_vendor.t($data.checkedAddr.contact_city),
    f: common_vendor.t($data.checkedAddr.contact_area),
    g: common_vendor.t($data.checkedAddr.contact_addr),
    h: common_vendor.o(($event) => $options.showAddrPopup()),
    i: common_vendor.f($data.cartList, (item, index, i0) => {
      return {
        a: item.thumb,
        b: common_vendor.t(item.name),
        c: common_vendor.t(item.spec),
        d: common_vendor.t(item.price),
        e: common_vendor.t(item.buy_num),
        f: index
      };
    }),
    j: $data.couponList.length
  }, $data.couponList.length ? {
    k: common_vendor.t($data.couponUsed),
    l: common_vendor.o(($event) => $options.popupCoupon())
  } : {}, {
    m: common_vendor.t($data.priceTotal),
    n: common_vendor.o(($event) => $options.createOrder()),
    o: common_vendor.f($data.couponList, (item, index, i0) => {
      return common_vendor.e({
        a: item.rebate_type == 1
      }, item.rebate_type == 1 ? {
        b: common_vendor.t(item.rebate)
      } : {}, {
        c: item.rebate_type == 2
      }, item.rebate_type == 2 ? {
        d: common_vendor.t(item.rebate)
      } : {}, {
        e: item.rebate_type == 3
      }, item.rebate_type == 3 ? common_vendor.e({
        f: item.rebate_scope.length
      }, item.rebate_scope.length ? {
        g: common_vendor.t(item.rebate_scope[0].product_name)
      } : {}) : {}, {
        h: common_vendor.t(item.std_pay),
        i: item.rebate_type == 1
      }, item.rebate_type == 1 ? {} : {}, {
        j: item.rebate_type == 2
      }, item.rebate_type == 2 ? {} : {}, {
        k: item.rebate_type == 3
      }, item.rebate_type == 3 ? {} : {}, {
        l: item.type_id == 1
      }, item.type_id == 1 ? {} : {}, {
        m: item.type_id == 2
      }, item.type_id == 2 ? {} : {}, {
        n: !item.is_std
      }, !item.is_std ? {} : {}, {
        o: item.is_std
      }, item.is_std ? {
        p: item.checked ? "../../static/icon/checked.png" : "../../static/icon/checkbox.png"
      } : {}, {
        q: common_vendor.t(item.exp_time),
        r: index,
        s: common_vendor.o(($event) => $options.checkedCoupon(index), index)
      });
    }),
    p: common_vendor.sr("popup", "309a4bfa-0"),
    q: common_vendor.o(() => {
    }),
    r: common_vendor.p({
      type: "bottom",
      ["background-color"]: "#FFFFFF"
    }),
    s: common_vendor.f($data.addrList, (item, index, i0) => {
      return common_vendor.e({
        a: item.id == $data.checkedAddr.id ? "../../static/icon/radioed.png" : "../../static/icon/radio.png",
        b: common_vendor.t(item.contact_name),
        c: common_vendor.t(item.contact_phone),
        d: item.is_default
      }, item.is_default ? {} : {}, {
        e: common_vendor.t(item.contact_province),
        f: common_vendor.t(item.contact_city),
        g: common_vendor.t(item.contact_area),
        h: common_vendor.t(item.contact_addr),
        i: index,
        j: common_vendor.o(($event) => $options.checkedAddrItem(item), index)
      });
    }),
    t: common_vendor.sr("addrPopup", "309a4bfa-1"),
    v: common_vendor.p({
      type: "bottom",
      ["background-color"]: "#FFFFFF"
    })
  });
}
const MiniProgramPage = /* @__PURE__ */ common_vendor._export_sfc(_sfc_main, [["render", _sfc_render]]);
wx.createPage(MiniProgramPage);
