"use strict";
const common_vendor = require("../../common/vendor.js");
const common_assets = require("../../common/assets.js");
const _sfc_main = {
  data() {
    return {
      show: false,
      // 使用Popup组件时,阻止禁止滚动穿透
      productInfo: {
        id: 0,
        name: "",
        score: 0,
        spec: "",
        stock: 0,
        thumb: "",
        description: ""
      },
      requestParam: {
        id: 0
      },
      // 数量
      quantity: 1,
      // 总价
      priceTotal: "0.00",
      // 规格选择按钮类型
      specBtnType: 1,
      // 1预约。2购物车
      // 地址列表
      addrList: [],
      // 已选地址
      checkedAddr: {
        id: 0,
        contact_name: "",
        contact_phone: "",
        contact_province: "",
        contact_city: "",
        contact_area: "",
        contact_addr: "",
        is_default: 0
      },
      //获取微信小程序分享按钮的信息
      StatusBarHeight: 0
    };
  },
  onLoad(param) {
    this.requestParam.id = param.id;
    var that = this;
    common_vendor.index.$on("addr_list_change", function(data) {
      that.addrList = data.list;
    });
  },
  onShow() {
    if (this.requestParam.id > 0) {
      this.$http.request("api/score_product/get_detail", this.requestParam).then((re) => {
        if (re.code == "success") {
          this.productInfo = re.data;
        }
      });
    }
    this.getStatusBarHeight();
  },
  methods: {
    // 地址弹出层
    showAddrPopup() {
      this.$refs.addrPopup.open("bottom");
    },
    // 规格弹出层
    showSpecPopup(type) {
      this.$refs.specPopup.open("bottom");
      this.getAddrList();
      this.priceHandler();
    },
    // 数量调整
    changeQuantity(number) {
      if (number != 0) {
        this.quantity = this.quantity + number;
      }
      if (this.quantity > this.productInfo.stock) {
        this.quantity = this.productInfo.stock;
        common_vendor.index.showToast({
          title: "库存不足",
          icon: "none"
        });
      }
      if (this.quantity < 1) {
        this.quantity = 1;
        common_vendor.index.showToast({ title: "数量不可以小于0", icon: "none" });
      }
      this.priceHandler();
    },
    // 创建订单
    createOrder() {
      if (!this.$checkAccess.alertCity())
        return;
      if (this.quantity < 1) {
        common_vendor.index.showToast({
          title: "至少兑换1个"
        });
        return;
      }
      if (this.productInfo.stock < 1) {
        common_vendor.index.showToast({
          title: "库存不足",
          icon: "none"
        });
        return;
      }
      if (!this.checkedAddr.id) {
        common_vendor.index.showToast({
          title: "请选择收货地址",
          icon: "none"
        });
        return;
      }
      this.$http.request("api/score_orders/create", { "product_id": this.productInfo.id, "buy_num": this.quantity, "addr_id": this.checkedAddr.id }, "post").then((re) => {
        if (re.code == "success") {
          this.productInfo.stock = this.productInfo.stock - this.quantity;
          this.$refs.specPopup.close();
          common_vendor.index.navigateTo({ url: "/pages/score/orders" });
          return;
        } else {
          common_vendor.index.showModal({ title: re.msg, showCancel: false });
        }
      });
    },
    // 计算价格
    priceHandler() {
      this.priceTotal = this.productInfo.score * this.quantity;
    },
    popupChange(e) {
      this.show = e.show;
    },
    // 选择地址
    checkedAddrItem(item) {
      this.checkedAddr = item;
      this.$refs.addrPopup.close();
    },
    getAddrList() {
      this.$http.request("api/custom_addr/get_list").then((callback) => {
        if (callback.code == "success") {
          this.addrList = callback.data;
          if (this.addrList.length) {
            for (let i in this.addrList) {
              if (this.addrList[i].is_default)
                this.checkedAddr = this.addrList[i];
            }
            if (!this.checkedAddr.id) {
              this.checkedAddr = this.addrList[this.addrList.length - 1];
            }
          }
        }
      });
    },
    getStatusBarHeight() {
      let SYSTEM_INFO = common_vendor.index.getSystemInfoSync();
      this.StatusBarHeight = SYSTEM_INFO.statusBarHeight || 10;
    },
    goBack() {
      common_vendor.index.navigateBack({
        success: () => {
        },
        fail: (err) => {
          common_vendor.index.reLaunch({
            url: "/pages/index/index"
          });
        }
      });
    }
  }
};
if (!Array) {
  const _easycom_uni_icons2 = common_vendor.resolveComponent("uni-icons");
  const _easycom_uni_popup2 = common_vendor.resolveComponent("uni-popup");
  (_easycom_uni_icons2 + _easycom_uni_popup2)();
}
const _easycom_uni_icons = () => "../../uni_modules/uni-icons/components/uni-icons/uni-icons.js";
const _easycom_uni_popup = () => "../../uni_modules/uni-popup/components/uni-popup/uni-popup.js";
if (!Math) {
  (_easycom_uni_icons + _easycom_uni_popup)();
}
function _sfc_render(_ctx, _cache, $props, $setup, $data, $options) {
  return common_vendor.e({
    a: "overflow:" + ($data.show ? "hidden" : "visible"),
    b: common_vendor.p({
      type: "back",
      color: "#fff",
      size: "20"
    }),
    c: $data.StatusBarHeight + "px",
    d: common_vendor.o((...args) => $options.goBack && $options.goBack(...args)),
    e: $data.productInfo.thumb,
    f: common_vendor.t($data.productInfo.stock),
    g: common_assets._imports_0,
    h: common_assets._imports_1$1,
    i: common_assets._imports_1$2,
    j: common_vendor.o(($event) => $options.showSpecPopup(2)),
    k: !$data.checkedAddr.id
  }, !$data.checkedAddr.id ? {} : {}, {
    l: common_vendor.t($data.checkedAddr.contact_name),
    m: common_vendor.t($data.checkedAddr.contact_phone),
    n: common_vendor.t($data.checkedAddr.contact_province),
    o: common_vendor.t($data.checkedAddr.contact_city),
    p: common_vendor.t($data.checkedAddr.contact_area),
    q: common_vendor.t($data.checkedAddr.contact_addr),
    r: common_vendor.o(($event) => $options.showAddrPopup()),
    s: $data.productInfo.thumb,
    t: common_vendor.t($data.productInfo.name),
    v: common_vendor.t($data.productInfo.score),
    w: common_assets._imports_2,
    x: common_vendor.o(($event) => $options.changeQuantity(-1)),
    y: common_vendor.o(($event) => $options.changeQuantity(0)),
    z: $data.quantity,
    A: common_vendor.o(($event) => $data.quantity = $event.detail.value),
    B: common_assets._imports_3,
    C: common_vendor.o(($event) => $options.changeQuantity(1)),
    D: common_vendor.t($data.productInfo.stock),
    E: common_vendor.t($data.priceTotal),
    F: common_vendor.o(($event) => $options.createOrder()),
    G: common_vendor.sr("specPopup", "f81ec0bc-1"),
    H: common_vendor.o($options.popupChange),
    I: common_vendor.p({
      show: true,
      type: "bottom",
      ["background-color"]: "#FFFFFF"
    }),
    J: common_vendor.f($data.addrList, (item, index, i0) => {
      return common_vendor.e({
        a: item.id == $data.checkedAddr.id ? "../../static/icon/radioed.png" : "../../static/icon/radio.png",
        b: common_vendor.t(item.contact_name),
        c: common_vendor.t(item.contact_phone),
        d: item.is_default
      }, item.is_default ? {} : {}, {
        e: common_vendor.t(item.contact_province),
        f: common_vendor.t(item.contact_city),
        g: common_vendor.t(item.contact_area),
        h: common_vendor.t(item.contact_addr),
        i: index,
        j: common_vendor.o(($event) => $options.checkedAddrItem(item), index)
      });
    }),
    K: common_vendor.sr("addrPopup", "f81ec0bc-2"),
    L: common_vendor.p({
      type: "bottom",
      ["background-color"]: "#FFFFFF"
    })
  });
}
const MiniProgramPage = /* @__PURE__ */ common_vendor._export_sfc(_sfc_main, [["render", _sfc_render]]);
wx.createPage(MiniProgramPage);
